from flask import Flask, render_template
from .digestion import DigestiveSystem

app = Flask(__name__, static_url_path="", static_folder="static")
de = DigestiveSystem()


def get_data():
    return de.dump()


@app.route("/")
def index():
    return render_template("home.html", data=get_data())


@app.route("/profile")
def profile():
    return render_template("profile.html", data=get_data())


@app.route("/environment")
def environment():
    return render_template("environment.html", data=get_data())


@app.route("/package/<pkgmgr>/<pkg>")
def package_info(pkgmgr, pkg):
    pkginfo = de.get_package(pkgmgr, pkg)
    return render_template(
        "package.html", pkgmgr=pkgmgr, pkg=pkg, data=get_data(), pkginfo=pkginfo
    )


@app.route("/package/<pkgmgr>/<pkg>/uninstall")
def package_uninstall(pkgmgr, pkg):
    pkginfo = de.poop_package(pkgmgr, pkg)
    return render_template(
        "package.html", pkgmgr=pkgmgr, pkg=pkg, data=get_data(), pkginfo=pkginfo
    )


if __name__ == "__main__":
    app.run()



import click
from pprint import pprint
from .app import app
from .digestion import DigestiveSystem


de = DigestiveSystem()
CONTEXT_SETTINGS = de.get()


@click.group(context_settings=CONTEXT_SETTINGS)
def lfnt():
    """For eating development-environment elephants."""
    pass


lfnt_group = lfnt.group(context_settings=CONTEXT_SETTINGS)
lfnt_command = lfnt.command(context_settings=CONTEXT_SETTINGS)


# browse
@lfnt_command
def browse():
    """Run in a web browser."""
    app.run()


# life-cycle
@lfnt_command
def init():
    """Initialize a configuration."""
    pass


# digestion
@lfnt_command
@click.option("-a", "--apt", multiple=True)
@click.option("-b", "--brew", multiple=True)
@click.option("-d", "--dnf", multiple=True)
def eat(apt, brew, dnf):
    """Ingest packages and applications."""
    for pkg in apt:
        print(de.eat_package("apt", pkg))
    for pkg in brew:
        print(de.eat_package("brew", pkg))
    for pkg in dnf:
        print(de.eat_package("dnf", pkg))


@lfnt_command
@click.option("-a", "--apt", multiple=True)
@click.option("-b", "--brew", multiple=True)
@click.option("-d", "--dnf", multiple=True)
def poop(apt, brew, dnf):
    """Eliminate packages and applications."""
    for pkg in apt:
        print(de.poop_package("apt", pkg))
    for pkg in brew:
        print(de.poop_package("brew", pkg))
    for pkg in dnf:
        print(de.poop_package("dnf", pkg))


@lfnt_command
def remember():
    """Save and commit environment."""
    pass


@lfnt_command
def dump():
    """Take a config dump."""
    pprint(de.dump())


if __name__ == "__main__":
    lfnt()



import os
import platform
import subprocess
from click_configfile import ConfigFileReader, Param, SectionSchema
from click_configfile import matches_section


def run_command(command):
    command_result = None
    try:
        command_result = subprocess.run(
            command,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
        )
    except Exception:
        pass

    return command_result


def get_config_files():
    return {}


def get_system():
    architecture, _ = platform.architecture()
    os_name = ""
    os_version = ""
    if os.path.exists("/etc/os-release"):
        with open("/etc/os-release") as f:
            for line in f:
                name = line.split("=")[0]
                value = line.split("=")[1].strip()
                if name == "PRETTY_NAME":
                    os_name = value.rstrip('"').lstrip('"')
                elif name == "VERSION_CODENAME":
                    os_version = value
    return {
        "os": platform.system(),
        "os_release": platform.release(),
        "os_name": os_name,
        "os_version": os_version,
        "machine": platform.machine(),
        "architecture": architecture,
    }


def get_packages():
    all_packages = {}
    for pkgmgr in ["apt", "brew", "dnf"]:
        which_cmd = run_command(["which", pkgmgr])
        if which_cmd is not None and which_cmd.returncode < 1:
            if pkgmgr == "apt":
                pkgs = run_command(["apt-mark", "showmanual"])
            if pkgmgr == "brew":
                pkgs = run_command(["brew", "leaves"])
            if pkgmgr == "dnf":
                pkgs = run_command(["dnf", "list", "installed"])
            all_packages[pkgmgr] = pkgs.stdout.decode().splitlines()
    return all_packages


class LocalEnv:
    def __init__(self):
        self.system = get_system()
        self.shell = os.getenv("SHELL")
        self.packages = None

    def get(self):
        if self.packages is None:
            self.packages = get_packages()

        return {
            "system": self.system,
            "packages": self.packages,
            "shell": self.shell,
        }


le = LocalEnv()


class ConfigSectionSchema(object):
    """Describes all config sections of this configuration file."""

    @matches_section("profile")
    class Profile(SectionSchema):
        name = Param(type=str)
        email = Param(type=str)
        git_provider = Param(type=str)
        config_repo = Param(type=str)


class ConfigFileProcessor(ConfigFileReader):
    home = os.getenv("HOME")
    config_files = [f"{home}/.lfntrc"]
    config_section_schemas = [
        ConfigSectionSchema.Profile,
    ]


CONTEXT_SETTINGS = dict(default_map=ConfigFileProcessor.read_config())


class LocalProfile:
    def __init__(self):
        self.context = CONTEXT_SETTINGS["default_map"]
        self.config_files = None

    def get(self):
        if self.config_files is None:
            self.config_files = get_config_files()

        return {
            "context": self.context,
            "config_files": self.config_files,
        }


lp = LocalProfile()


class DigestiveSystem:
    def __init__(self):
        pass

    def dump(self):
        return {
            "profile": lp.get(),
            "environment": le.get(),
        }

    def get(self):
        return CONTEXT_SETTINGS

    def get_package(self, pkgmgr, pkg):
        pkg_data = run_command([pkgmgr, "info", pkg])
        return pkg_data.stdout.decode().splitlines()

    def eat_package(self, pkgmgr, pkg):
        action = "install"
        command = [pkgmgr, action, pkg]
        pkg_data = run_command(command)
        return pkg_data.stdout.decode().splitlines()

    def poop_package(self, pkgmgr, pkg):
        action = "uninstall"
        if pkgmgr in ["apt"]:
            action = "remove"
        pkg_data = run_command([pkgmgr, action, pkg])
        return pkg_data.stdout.decode().splitlines()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['lfnt']

package_data = \
{'': ['*'], 'lfnt': ['static/*', 'templates/*']}

install_requires = \
['Flask>=2.0.3,<3.0.0',
 'GitPython>=3.1.27,<4.0.0',
 'awscli>=1.22.82,<2.0.0',
 'click-configfile>=0.2.3,<0.3.0',
 'click>=8.0.4,<9.0.0',
 'configparser>=5.2.0,<6.0.0',
 'pulumi>=3.27.0,<4.0.0']

entry_points = \
{'console_scripts': ['lfnt = lfnt.cli:lfnt']}

setup_kwargs = {
    'name': 'lfnt',
    'version': '0.1.11',
    'description': 'For eating development-environment elephants.',
    'long_description': "[![PyPI version](https://badge.fury.io/py/lfnt.svg)](https://badge.fury.io/py/lfnt)\n\n# Elephant (lfnt)\n\n`lfnt` eats development environments.\n\n## What??\n\nSetting up a development environment is a lot like eating an elephant—you have to take it one bite at a time.\nWhether you're such a noob that you don't even know what a noob is or you're such a vet that you already have opinions about this project, you know that starting from scratch is daunting.\nMeanwhile, we all keep eating, and re-eating, the same elephant!\n\nIn my humble opinion, that's just stupid.\n\nBut I'm not alone.\nDevelopers are now commonly adding their config files and installation scripts to their own code repos.\nYet even that is still a pain in the ass to manage, especially when it comes down to every little detail.\n\nThat's where `lfnt` comes in useful—it handles all of the grunt-work for you.\n`lfnt` eases the pain of managing your development environment by:\n\n* Maintaining your configuration repository\n* Keeping track of what packages have been installed and how\n* Restoring your whole setup to a new machine from your configuration repository\n* Providing a platform for environment sharing and test-driving others'\n\nSo just install this package and let `lfnt` do the rest!\n\n## How??\n\n`lfnt` is written in Python3, which means that most workstations are already equipped to use it.\nIt allows you to interact with your environment from a command-line and/or visually from a local web app.\nYou can use it to create a new configuration repository or sync with an existing one—and even perform automatic backups.\n\nAll you need to do is start up a terminal and run:\n\n`pip install lfnt`\n\nAfter the installation is complete, run `lfnt` with no arguments for a synopsis.\nFor example:\n\n```\n$ lfnt\nUsage: lfnt [OPTIONS] COMMAND [ARGS]...\n\n  For eating development-environment elephants.\n\nOptions:\n  --help  Show this message and exit.\n\nCommands:\n  browse    Run in a web browser.\n  dump      Take a config dump.\n  eat       Ingest packages and applications.\n  init      Initialize a configuration.\n  poop      Eliminate packages and applications.\n  remember  Save and commit environment.\n```\n",
    'author': 'Dan Swartz',
    'author_email': '2fifty6@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/2fifty6/lfnt',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
